@@ -5,10 +5,12 @@ from requests import Response
 from chargebeecli.config.Configuration import Configuration
 from chargebeecli.constants.constants import Formats, ACTIVE_THEME_SECTION_NAME, ACTIVE_PROFILE_SECTION_NAME, \
     API_KEY_NAME, ACCOUNT_KEY_NAME
+from chargebeecli.constants.error_messages import PROFILE_NOT_SET, PROFILE_NAME_IS_NONE
 from chargebeecli.export.Exporter import Exporter
 from chargebeecli.formater.response_formatter import ResponseFormatter
 from chargebeecli.printer.printer import Printer
 from chargebeecli.processors.processor import Processor
+from chargebeecli.util.printer_util import custom_print
 from chargebeecli.validator.validator import Validator
 
 
@@ -44,17 +46,20 @@ class Profile(Processor, Validator, ResponseFormatter, Exporter, Printer):
         response = Response()
         response.status_code = 200
         if resource_id is None:
-            __active_profile = Configuration.Instance().fetch_section(ACTIVE_PROFILE_SECTION_NAME, 'primary')
-        else:
-            __active_profile = resource_id
-            if __active_profile not in Configuration.Instance().fetch_available_sections():
-                exit()
+            custom_print(PROFILE_NAME_IS_NONE, err=True)
+            exit()
+
+        __active_profile = resource_id
+        if __active_profile not in Configuration.Instance().fetch_available_sections():
+            custom_print(PROFILE_NOT_SET % resource_id, err=True)
+            exit()
 
         if __active_profile is None:
             return response
         res = {"profile": {"name": __active_profile,
                            API_KEY_NAME: Configuration.Instance().fetch_section(__active_profile, API_KEY_NAME),
-                           ACCOUNT_KEY_NAME: Configuration.Instance().fetch_section(__active_profile, ACCOUNT_KEY_NAME)}}
+                           ACCOUNT_KEY_NAME: Configuration.Instance().fetch_section(__active_profile,
+                                                                                    ACCOUNT_KEY_NAME)}}
         response._content = json.dumps(res).encode('utf-8')
         return response
 
@@ -63,6 +68,7 @@ class Profile(Processor, Validator, ResponseFormatter, Exporter, Printer):
         response.status_code = 200
         __sections = Configuration.Instance().fetch_available_sections()
         if len(__sections) == 0:
+            response._content = json.dumps({'list': []}).encode('utf-8')
             return response
 
         res = []
